@@ -206,4 +206,4 @@ class AdatecInterface(EasyPedidoInterfaceBase):
 
     def update_variants(self, key_field_name, location_codes=None, price_list_codes=None):
         content = self.get_variants_content(location_codes, price_list_codes)
-        return super(AdatecInterface, self).update_variants(key_field_name, content=content)
+        return super(AdatecInterface, self).update_variants(key_field_name, content=content or '')
